@@ -1,3 +1,5 @@
+import os
+from contextlib import contextmanager
 from collections import defaultdict
 import importlib.util
 
@@ -68,6 +70,20 @@ def load_pyom(pyom_lib):
     return pyom_obj
 
 
+@contextmanager
+def suppress_stdout(stdout_fd=1):
+    old_stdout = os.dup(stdout_fd)
+
+    with open(os.devnull, "wb") as void:
+        os.dup2(void.fileno(), stdout_fd)
+
+    try:
+        yield
+    finally:
+        with os.fdopen(old_stdout, "wb") as std:
+            os.dup2(std.fileno(), stdout_fd)
+
+
 def pyom_from_state(state, pyom_obj, ignore_attrs=None, init_streamfunction=True):
     """Force-updates internal PyOM library state to match given Veros state."""
     if ignore_attrs is None:
@@ -127,7 +143,8 @@ def pyom_from_state(state, pyom_obj, ignore_attrs=None, init_streamfunction=True
         set_fortran_attr(var, val)
 
     if init_streamfunction:
-        pyom_obj.streamfunction_init()
+        with suppress_stdout():
+            pyom_obj.streamfunction_init()
 
         for var in STREAMFUNCTION_VARS:
             set_fortran_attr(var, state.variables.get(var))
@@ -414,16 +431,16 @@ def run_pyom(pyom_obj, set_forcing, after_timestep=None):
         m.taup1 = orig_taum1
 
         # NOTE: benchmarks parse this, do not change / remove
-        logger.debug("Time step took {}s", timers["main"].get_last_time())
+        logger.debug("Time step took {}s", timers["main"].last_time)
 
     logger.debug("Timing summary:")
-    logger.debug(" setup time summary       = {}s", timers["setup"].get_time())
-    logger.debug(" main loop time summary   = {}s", timers["main"].get_time())
-    logger.debug("     momentum             = {}s", timers["momentum"].get_time())
-    logger.debug("     thermodynamics       = {}s", timers["temperature"].get_time())
-    logger.debug("     EKE                  = {}s", timers["eke"].get_time())
-    logger.debug("     IDEMIX               = {}s", timers["idemix"].get_time())
-    logger.debug("     TKE                  = {}s", timers["tke"].get_time())
+    logger.debug(" setup time summary       = {}s", timers["setup"].total_time)
+    logger.debug(" main loop time summary   = {}s", timers["main"].total_time)
+    logger.debug("     momentum             = {}s", timers["momentum"].total_time)
+    logger.debug("     thermodynamics       = {}s", timers["temperature"].total_time)
+    logger.debug("     EKE                  = {}s", timers["eke"].total_time)
+    logger.debug("     IDEMIX               = {}s", timers["idemix"].total_time)
+    logger.debug("     TKE                  = {}s", timers["tke"].total_time)
 
 
 def _generate_random_var(state, var):
@@ -431,6 +448,7 @@ def _generate_random_var(state, var):
 
     meta = state.var_meta[var]
     shape = get_shape(state.dimensions, meta.dims)
+    global_shape = get_shape(state.dimensions, meta.dims, local=False)
 
     if var == "kbot":
         val = onp.zeros(shape)
@@ -441,19 +459,19 @@ def _generate_random_var(state, var):
 
     if var in ("dxt", "dxu", "dyt", "dyu"):
         if state.settings.coord_degree:
-            val = 1 + 1e-2 * onp.random.randn(*shape)
+            val = 80 / global_shape[0] * (1 + 1e-2 * onp.random.randn(*shape))
         else:
-            val = 10e3 + 100 * onp.random.randn(*shape)
+            val = 10_000e3 / global_shape[0] * (1 + 1e-2 * onp.random.randn(*shape))
         return val
 
     if var in ("dzt", "dzw"):
-        val = 100 + onp.random.randn(*shape)
+        val = 6000 / global_shape[0] * (1 + 1e-2 * onp.random.randn(*shape))
         return val
 
     if onp.issubdtype(onp.dtype(meta.dtype), onp.floating):
         val = onp.random.randn(*shape)
         if var in ("salt",):
-            val = onp.abs(val)
+            val = 35 + val
 
         return val
 
@@ -496,6 +514,7 @@ def get_random_state(pyom2_lib=None, extra_settings=None):
     # ensure that masks and geometries are consistent with grid spacings
     numerics.calc_grid(state)
     numerics.calc_topo(state)
+
     streamfunction.streamfunction_init(state)
 
     if pyom2_lib is None:
